.. This file is a part of the AnyBlok project
..
..    Copyright (C) 2014 Jean-Sebastien SUZANNE <jssuzanne@anybox.fr>
..
.. This Source Code Form is subject to the terms of the Mozilla Public License,
.. v. 2.0. If a copy of the MPL was not distributed with this file,You can
.. obtain one at http://mozilla.org/MPL/2.0/.

.. contents::

ROADMAP
=======

To implement
------------

* Add slogan
* Update doc
* Need improve alembic, sqlalchemy-util
* Refactor the engine declarations to have master / slave(s) configuration
* Addons for sqlalchemy : http://sqlalchemy-utils.readthedocs.org/en/latest/installation.html

Library to include
------------------

* full text search: https://pypi.python.org/pypi/SQLAlchemy-FullText-Search/0.2
* internationalisation: https://pypi.python.org/pypi/SQLAlchemy-i18n/0.8.2
* sqltap http://sqltap.inconshreveable.com, profiling and introspection for SQLAlchemy applications
* Crypt https://bitbucket.org/zzzeek/sqlalchemy/wiki/UsageRecipes/DatabaseCrypt
* profiling https://bitbucket.org/zzzeek/sqlalchemy/wiki/UsageRecipes/Profiling

Functionnality which need a sprint
----------------------------------

* Tasks Management
* Internalization
* Ancestor left / right
